savepagenow — savepagenow documentation

# savepagenow

A simple Python wrapper and command-line interface for archive.org’s “Save Page Now” capturing service

- Installation
- Python Usage
- Command-line usage
- Customizing the user agent
- Exceptions

## Links

- Documentation: palewi.re/docs/savepagenow/

- Code: github.com/palewire/savepagenow

- Issues: github.com/palewire/savepagenow/issues

- Packaging: pypi.org/project/savepagenow